==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V2beta1ObjectMetricStatusFluent.java <==
package io.kubernetes.client.models;

import java.lang.Deprecated;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Boolean;

public interface V2beta1ObjectMetricStatusFluent<A extends V2beta1ObjectMetricStatusFluent<A>> extends Fluent<A>{


    public String getCurrentValue();
    public A withCurrentValue(String currentValue);
    public Boolean hasCurrentValue();
    public String getMetricName();
    public A withMetricName(String metricName);
    public Boolean hasMetricName();
    
/**
 * This method has been deprecated, please use method buildTarget instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1CrossVersionObjectReference getTarget();
    public V2beta1CrossVersionObjectReference buildTarget();
    public A withTarget(V2beta1CrossVersionObjectReference target);
    public Boolean hasTarget();
    public V2beta1ObjectMetricStatusFluent.TargetNested<A> withNewTarget();
    public V2beta1ObjectMetricStatusFluent.TargetNested<A> withNewTargetLike(V2beta1CrossVersionObjectReference item);
    public V2beta1ObjectMetricStatusFluent.TargetNested<A> editTarget();
    public V2beta1ObjectMetricStatusFluent.TargetNested<A> editOrNewTarget();
    public V2beta1ObjectMetricStatusFluent.TargetNested<A> editOrNewTargetLike(V2beta1CrossVersionObjectReference item);

    public interface TargetNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1CrossVersionObjectReferenceFluent<V2beta1ObjectMetricStatusFluent.TargetNested<N>>{

        
    public N and();    public N endTarget();
}


}

==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V2beta1ObjectMetricStatusFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V2beta1ObjectMetricStatusFluent<A extends V2beta1ObjectMetricStatusFluent<A>> extends Fluent<A>{


    public String getAverageValue();
    public A withAverageValue(String averageValue);
    public Boolean hasAverageValue();
    public String getCurrentValue();
    public A withCurrentValue(String currentValue);
    public Boolean hasCurrentValue();
    public String getMetricName();
    public A withMetricName(String metricName);
    public Boolean hasMetricName();
    
/**
 * This method has been deprecated, please use method buildSelector instead.
 * @return The buildable object.
 */
@Deprecated public V1LabelSelector getSelector();
    public V1LabelSelector buildSelector();
    public A withSelector(V1LabelSelector selector);
    public Boolean hasSelector();
    public V2beta1ObjectMetricStatusFluent.SelectorNested<A> withNewSelector();
    public V2beta1ObjectMetricStatusFluent.SelectorNested<A> withNewSelectorLike(V1LabelSelector item);
    public V2beta1ObjectMetricStatusFluent.SelectorNested<A> editSelector();
    public V2beta1ObjectMetricStatusFluent.SelectorNested<A> editOrNewSelector();
    public V2beta1ObjectMetricStatusFluent.SelectorNested<A> editOrNewSelectorLike(V1LabelSelector item);
    
/**
 * This method has been deprecated, please use method buildTarget instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1CrossVersionObjectReference getTarget();
    public V2beta1CrossVersionObjectReference buildTarget();
    public A withTarget(V2beta1CrossVersionObjectReference target);
    public Boolean hasTarget();
    public V2beta1ObjectMetricStatusFluent.TargetNested<A> withNewTarget();
    public V2beta1ObjectMetricStatusFluent.TargetNested<A> withNewTargetLike(V2beta1CrossVersionObjectReference item);
    public V2beta1ObjectMetricStatusFluent.TargetNested<A> editTarget();
    public V2beta1ObjectMetricStatusFluent.TargetNested<A> editOrNewTarget();
    public V2beta1ObjectMetricStatusFluent.TargetNested<A> editOrNewTargetLike(V2beta1CrossVersionObjectReference item);

    public interface SelectorNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LabelSelectorFluent<V2beta1ObjectMetricStatusFluent.SelectorNested<N>>{

        
    public N and();    public N endSelector();
}
    public interface TargetNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1CrossVersionObjectReferenceFluent<V2beta1ObjectMetricStatusFluent.TargetNested<N>>{

        
    public N and();    public N endTarget();
}


}
